@@ -92,32 +92,13 @@ set -x
 
 find . -name 'px*.whl' -delete
 
-# Build the release
+# Test and build the release so we know it works before we release it
 tox
 
-# Make a relelase virtualenv
-ENVDIR="$(mktemp -d)"
-function cleanup {
-  rm -rf "${ENVDIR}"
-}
-trap cleanup EXIT
-
-virtualenv "${ENVDIR}"
-# shellcheck source=/dev/null
-. "${ENVDIR}"/bin/activate
-
-# Work around having an old version of OpenSSL
+# Mark new release on Github.
 #
-# https://github.com/pypa/twine/issues/273#issuecomment-334911815
-pip install "ndg-httpsclient == 0.4.3"
-
-pip install "twine == 4.0.2"
-
-# Upload!
-echo
-twine upload --repository pypi dist/pxpx-*-py3-none-any.whl
-
-# Mark new release on Github
+# Note that this implicitly triggers uploads to Homebrew and PyPI through GitHub
+# actions configured in .github/workflows.
 git push --tags
 
 cat <<EOM
@@ -138,24 +119,9 @@ read -r -p "Press ENTER when done: "
 
 cat <<EOM
 
-==
-Now, make a PR for bumping the homebrew packaging version to $NEW_VERSION_NUMBER:
-
-  brew bump-formula-pr --strict px --tag=$NEW_VERSION_NUMBER --revision=$(git rev-parse HEAD)
-
-In that PR, make sure to bump the dateutil dependency as requested here:
-  https://github.com/Homebrew/homebrew-core/pull/83331#pullrequestreview-730162574
-
-EOM
-
-# Ref: https://github.com/Homebrew/homebrew-core/actions/runs/1132207320
-read -r -p "Press ENTER when the PR CI has passed, this took 22 minutes for release 1.5.1: "
-
-cat <<EOM
-
 ==
 Your release should now be visible here:
 * https://github.com/walles/px/releases/latest
-* https://formulae.brew.sh/formula/px
+* https://formulae.brew.sh/formula/px (or at least there should be a PR open)
 * https://pypi.python.org/pypi/pxpx
 EOM
