@@ -1,13 +1,12 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 import os
 import time
 import signal
 
 
-def receiveSignal(signalNumber, frame):
+def receiveSignal(signalNumber, _):
     print("Received signal " + str(signalNumber))
-    return
 
 
 signal.signal(signal.SIGTERM, receiveSignal)
